/*
 *  Copyright 2006 Guillermo Castro
 *  
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *  
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 */
package org.javageek.wicket;

import domain.Blog;
import wicket.markup.html.WebPage;
import wicket.markup.html.basic.Label;

/**
 * Base Page class. Every page for the web application should subclass this page, as it contains
 * common components and the html template.
 * 
 * @author Guillermo Castro
 */
public abstract class BasePage extends WebPage {
	/**
	 * Default Constructor
	 */
	public BasePage() {
		Blog blog = getBlog();

		add(new Label("blogName", blog.getName()));
		add(new Label("blogDescription", blog.getDescription()));

	}

	/**
	 * Obtains the Blog domain object
	 * 
	 * @return the Blog domain object
	 */
	public Blog getBlog() {
		return BlogApplication.instance().getBlog();
	}
}
