/*
 *  Copyright 2006 Guillermo Castro
 *  
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *  
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 */
package org.javageek.wicket;

import wicket.Application;
import wicket.protocol.http.WebApplication;
import wicket.settings.Settings;
import domain.Blog;
import domain.BlogService;

/**
 * Main Application class. This class defines the settings for the web application
 * 
 * @author Guillermo Castro
 */
public class BlogApplication extends WebApplication {

	private BlogService blogService = new BlogService();

	/**
	 * Default constructor. This is where the application settings are set.
	 */
	public BlogApplication() {
		Settings settings = (Settings) getApplicationSettings();
		configure(DEVELOPMENT);
		settings.setStripWicketTags(true);
		settings.setDefaultMarkupEncoding("UTF-8");
		settings.setStripXmlDeclarationFromOutput(false);
		settings.setBufferResponse(false);
		settings.setRenderStrategy(Settings.REDIRECT_TO_RENDER);
	}

	/**
	 * @see wicket.Application#getHomePage()
	 */
	@Override
	public Class getHomePage() {
		return Index.class;
	}

	/**
	 * Return an instance of this application.
	 * 
	 * @return a BlogApplication instance
	 */
	public static final BlogApplication instance() {
		return (BlogApplication) Application.get();
	}

	/**
	 * Convenience method to get the Blog domain class.
	 * 
	 * @return the Blog domain class.
	 */
	public Blog getBlog() {
		return blogService.getBlog();
	}

}
