/*
 *  Copyright 2006 Guillermo Castro
 *  
 *  Licensed under the Apache License, Version 2.0 (the "License"); 
 *  you may not use this file except in compliance with the License. 
 *  You may obtain a copy of the License at 
 *  
 *      http://www.apache.org/licenses/LICENSE-2.0 
 *  
 *  Unless required by applicable law or agreed to in writing, software 
 *  distributed under the License is distributed on an "AS IS" BASIS, 
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 *  See the License for the specific language governing permissions and 
 *  limitations under the License.
 */
package org.javageek.wicket;

import java.text.DateFormat;
import java.util.List;

import wicket.PageParameters;
import wicket.markup.html.basic.Label;
import wicket.markup.html.link.BookmarkablePageLink;
import wicket.markup.html.list.ListItem;
import wicket.markup.html.list.ListView;
import wicket.model.IModel;
import wicket.model.LoadableDetachableModel;
import wicket.util.string.Strings;
import domain.BlogEntry;

/**
 * @author Guillermo Castro
 */
public class Index extends BasePage {

	/**
	 * Default constructor. Build the page
	 */
	public Index() {

		IModel entriesModel = new LoadableDetachableModel() {
			@Override
			protected Object load() {
				return getBlog().getBlogEntries();
			}

		};

		add(new ListView("blogEntries", entriesModel) {
			@Override
			protected IModel getListItemModel(IModel model, int index) {
				List entries = (List) model.getObject(this);
				BlogEntry current = (BlogEntry) entries.get(index);
				return new BlogEntryModel(current);
			}

			@Override
			protected void populateItem(ListItem item) {
				final BlogEntry entry = (BlogEntry) item.getModelObject();
				final String excerpt = entry.getExcerpt();
				final boolean hasExcerpt = !Strings.isEmpty(excerpt);

				item.add(new Label("entryTitle", entry.getTitle()));

				PageParameters params = new PageParameters();
				params.put("id", entry.getId());
				item.add(new BookmarkablePageLink("viewBlogEntry", ViewBlogEntry.class, params) {
					@Override
					public boolean isVisible() {
						return hasExcerpt;
					}
				});

				if (hasExcerpt) {
					item.add(new Label("entryBody", entry.getExcerpt()).setEscapeModelStrings(false));
				} else {
					item.add(new Label("entryBody", entry.getBody()).setEscapeModelStrings(false));
				}

				DateFormat df = DateFormat.getDateTimeInstance(DateFormat.LONG, DateFormat.LONG, getBlog().getLocale());
				item.add(new Label("entryDate", df.format(entry.getDate())));
			}
		});
		add(new Label("pageTitle", getBlog().getName()));
	}
}
